@@ -7,15 +7,23 @@ from random import randint
 from typing import Optional
 
 import websocket
+from websocket import WebSocketTimeoutException
 
-from .error import OBSSDKError
+from .error import OBSSDKError, OBSSDKTimeoutError
+
+logger = logging.getLogger(__name__)
 
 
 class ObsClient:
-    logger = logging.getLogger("baseclient.obsclient")
-
     def __init__(self, **kwargs):
-        defaultkwargs = {"host": "localhost", "port": 4455, "password": "", "subs": 0}
+        self.logger = logger.getChild(self.__class__.__name__)
+        defaultkwargs = {
+            "host": "localhost",
+            "port": 4455,
+            "password": "",
+            "subs": 0,
+            "timeout": None,
+        }
         if not any(key in kwargs for key in ("host", "port", "password")):
             kwargs |= self._conn_from_toml()
         kwargs = defaultkwargs | kwargs
@@ -23,14 +31,21 @@ class ObsClient:
             setattr(self, attr, val)
 
         self.logger.info(
-            "Connecting with parameters: host='{host}' port={port} password='{password}' subs={subs}".format(
+            "Connecting with parameters: host='{host}' port={port} password='{password}' subs={subs} timeout={timeout}".format(
                 **self.__dict__
             )
         )
 
-        self.ws = websocket.WebSocket()
-        self.ws.connect(f"ws://{self.host}:{self.port}")
-        self.server_hello = json.loads(self.ws.recv())
+        try:
+            self.ws = websocket.WebSocket()
+            self.ws.connect(f"ws://{self.host}:{self.port}", timeout=self.timeout)
+            self.server_hello = json.loads(self.ws.recv())
+        except ValueError as e:
+            self.logger.error(f"{type(e).__name__}: {e}")
+            raise
+        except (ConnectionRefusedError, TimeoutError, WebSocketTimeoutException) as e:
+            self.logger.exception(f"{type(e).__name__}: {e}")
+            raise
 
     def _conn_from_toml(self) -> dict:
         try:
@@ -82,9 +97,9 @@ class ObsClient:
             auth = base64.b64encode(
                 hashlib.sha256(
                     (
-                        secret.decode()
-                        + self.server_hello["d"]["authentication"]["challenge"]
-                    ).encode()
+                        secret
+                        + self.server_hello["d"]["authentication"]["challenge"].encode()
+                    )
                 ).digest()
             ).decode()
 
@@ -93,9 +108,15 @@ class ObsClient:
         self.ws.send(json.dumps(payload))
         try:
             response = json.loads(self.ws.recv())
-            return response["op"] == 2
+            if response["op"] != 2:
+                raise OBSSDKError(
+                    "failed to identify client with the server, expected response with OpCode 2"
+                )
+            return response["d"]
         except json.decoder.JSONDecodeError:
-            raise OBSSDKError("failed to identify client with the server")
+            raise OBSSDKError(
+                "failed to identify client with the server, please check connection settings"
+            )
 
     def req(self, req_type, req_data=None):
         payload = {
@@ -105,7 +126,11 @@ class ObsClient:
         if req_data:
             payload["d"]["requestData"] = req_data
         self.logger.debug(f"Sending request {payload}")
-        self.ws.send(json.dumps(payload))
-        response = json.loads(self.ws.recv())
+        try:
+            self.ws.send(json.dumps(payload))
+            response = json.loads(self.ws.recv())
+        except WebSocketTimeoutException as e:
+            self.logger.exception(f"{type(e).__name__}: {e}")
+            raise OBSSDKTimeoutError("Timeout while trying to send the request") from e
         self.logger.debug(f"Response received {response}")
         return response["d"]
