@@ -1,7 +1,8 @@
 import logging
+from warnings import warn
 
 from .baseclient import ObsClient
-from .error import OBSSDKError
+from .error import OBSSDKError, OBSSDKRequestError
 from .util import as_dataclass
 
 """
@@ -43,14 +44,17 @@ class ReqClient:
         return type(self).__name__
 
     def send(self, param, data=None, raw=False):
-        response = self.base_client.req(param, data)
-        if not response["requestStatus"]["result"]:
-            error = (
-                f"Request {response['requestType']} returned code {response['requestStatus']['code']}",
-            )
-            if "comment" in response["requestStatus"]:
-                error += (f"With message: {response['requestStatus']['comment']}",)
-            raise OBSSDKError("\n".join(error))
+        try:
+            response = self.base_client.req(param, data)
+            if not response["requestStatus"]["result"]:
+                raise OBSSDKRequestError(
+                    response["requestType"],
+                    response["requestStatus"]["code"],
+                    response["requestStatus"].get("comment"),
+                )
+        except OBSSDKRequestError as e:
+            self.logger.exception(f"{type(e).__name__}: {e}")
+            raise
         if "responseData" in response:
             if raw:
                 return response["responseData"]
@@ -429,6 +433,19 @@ class ReqClient:
         """
         return self.send("GetRecordDirectory")
 
+    def set_record_directory(self, recordDirectory):
+        """
+        Sets the current directory that the record output writes files to. 
+        IMPORTANT NOTE: Requires obs websocket v5.3 or higher.
+
+        :param recordDirectory: Output directory
+        :type recordDirectory: str
+        """
+        payload = {
+            "recordDirectory": recordDirectory,
+        }
+        return self.send("SetRecordDirectory", payload)
+    
     def get_source_active(self, name):
         """
         Gets the active and show state of a source
@@ -1935,3 +1952,66 @@ class ReqClient:
 
         """
         return self.send("GetMonitorList")
+
+    def open_video_mix_projector(
+        self, video_mix_type, monitor_index=-1, projector_geometry=None
+    ):
+        """
+        Opens a projector for a specific output video mix.
+
+        The available mix types are:
+            OBS_WEBSOCKET_VIDEO_MIX_TYPE_PREVIEW
+            OBS_WEBSOCKET_VIDEO_MIX_TYPE_PROGRAM
+            OBS_WEBSOCKET_VIDEO_MIX_TYPE_MULTIVIEW
+
+        :param video_mix_type: Type of mix to open.
+        :type video_mix_type:  str
+        :param monitor_index: Monitor index, use GetMonitorList to obtain index
+        :type monitor_index:  int
+        :param projector_geometry:
+            Size/Position data for a windowed projector, in Qt Base64 encoded format.
+            Mutually exclusive with monitorIndex
+        :type projector_geometry: str
+
+        """
+        warn(
+            "open_video_mix_projector request serves to provide feature parity with 4.x. "
+            "It is very likely to be changed/deprecated in a future release.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        payload = {
+            "videoMixType": video_mix_type,
+            "monitorIndex": monitor_index,
+            "projectorGeometry": projector_geometry,
+        }
+        self.send("OpenVideoMixProjector", payload)
+
+    def open_source_projector(
+        self, source_name, monitor_index=-1, projector_geometry=None
+    ):
+        """
+        Opens a projector for a source.
+
+        :param source_name: Name of the source to open a projector for
+        :type source_name:  str
+        :param monitor_index: Monitor index, use GetMonitorList to obtain index
+        :type monitor_index:  int
+        :param projector_geometry:
+            Size/Position data for a windowed projector, in Qt Base64 encoded format.
+            Mutually exclusive with monitorIndex
+        :type projector_geometry: str
+
+        """
+        warn(
+            "open_source_projector request serves to provide feature parity with 4.x. "
+            "It is very likely to be changed/deprecated in a future release.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        payload = {
+            "sourceName": source_name,
+            "monitorIndex": monitor_index,
+            "projectorGeometry": projector_geometry,
+        }
+        self.send("OpenSourceProjector", payload)
